@@ -19,7 +19,7 @@ use base qw(POE::Component::Pluggable);
 use POE::Component::Pluggable::Constants qw(:ALL);
 use vars qw($VERSION);
 
-$VERSION = '2.10';
+$VERSION = '2.12';
 
 sub spawn {
   my ($package,$alias,$hash) = splice @_, 0, 3;
@@ -427,7 +427,7 @@ server.
 
 =over
 
-=item spawn
+=item C<spawn>
 
 Takes two arguments, a kernel alias to christen the new component with and a hashref. 
 
@@ -448,11 +448,11 @@ If 'NNTPServer' is not specified, the default is 'news', unless the environment
 
 =over
 
-=item session_id
+=item C<session_id>
 
 Returns the session ID of the component's POE::Session.
 
-=item connected
+=item C<connected>
 
 Indicates true or false as to whether the component is currently connected to a server or not.
 
@@ -464,29 +464,29 @@ The component accepts the following events:
 
 =over
 
-=item register
+=item C<register>
 
 Takes N arguments: a list of event names that your session wants to listen for, minus the 'nntp_' prefix, ( this is 
 similar to L<POE::Component::IRC> ). 
 
 Registering for 'all' will cause it to send all NNTP-related events to you; this is the easiest way to handle it.
 
-=item unregister
+=item C<unregister>
 
 Takes N arguments: a list of event names which you don't want to receive. If you've previously done a 'register' for a particular event which you no longer care about, this event will tell the NNTP connection to stop sending them to you. (If you haven't, it just ignores you. No big deal).
 
 Please ensure that you always 'unregister' with the component before asking it to 'shutdown'.
 
-=item connect
+=item C<connect>
 
 Takes no arguments. Tells the NNTP component to start up a connection to the previously specified NNTP server. You will 
 receive a 'nntp_connected' event.
 
-=item disconnect
+=item C<disconnect>
 
 Takes no arguments. Terminates the socket connection ungracelessly.
 
-=item shutdown
+=item C<shutdown>
 
 Takes no arguments. Terminates the component.
 
@@ -498,76 +498,76 @@ The following are implemented NNTP commands, check RFC 977 L<http://www.faqs.org
 
 =over
 
-=item article
+=item C<article>
 
 Takes either a valid message-ID or a numeric-ID.
 
-=item body
+=item C<body>
 
 Takes either a valid message-ID or a numeric-ID.
 
-=item head
+=item C<head>
 
 Takes either a valid message-ID or a numeric-ID.
 
-=item stat
+=item C<stat>
 
 Takes either a valid message-ID or a numeric-ID.
 
-=item group
+=item C<group>
 
 Takes the name of a newsgroup to select.
 
-=item help
+=item C<help>
 
 Takes no arguments.
 
-=item ihave
+=item C<ihave>
 
 Takes one argument, a message-ID.
 
-=item last
+=item C<last>
 
 Takes no arguments.
 
-=item list
+=item C<list>
 
 Takes no arguments.
 
-=item newgroups
+=item C<newgroups>
 
 Can take up to four arguments: a date, a time, optionally you can specify GMT and an optional list of distributions.
 
-=item newnews
+=item C<newnews>
 
 Can take up to five arguments: a newsgroup, a date, a time, optionally you can specify GMT and an optional list of distributions.
 
-=item next
+=item C<next>
 
 Takes no arguments.
 
-=item post
+=item C<post>
 
 Takes no arguments. Once you have sent this expect to receive an 'nntp_340' event. When you receive this send the component a 'send_post' event, see below.
 
-=item send_post
+=item C<send_post>
 
 Takes one argument, an array ref containing the message to be posted, one line of the message to each array element.
 
-=item quit
+=item C<quit>
 
 Takes no arguments.
 
-=item slave
+=item C<slave>
 
 Takes no arguments.
 
-=item authinfo
+=item C<authinfo>
 
 Takes two arguments: first argument is either 'user' or 'pass', second argument is the user or password, respectively. 
 Not technically part of RFC 977 L<http://www.faqs.org/rfcs/rfc977.html>, but covered in RFC 2980 L<http://www.faqs.org/rfcs/rfc2980.html>.
 
-=item send_cmd
+=item C<send_cmd>
 
 The catch-all event :) Anything sent to this is passed directly to the NNTP server. Use this to implement any non-RFC 
 commands that you want, or to completely bypass all the above if you so desire.
@@ -580,25 +580,25 @@ The following events are generated by the component:
 
 =over
 
-=item nntp_registered
+=item C<nntp_registered>
 
 Generated when you either explicitly 'register' with the component or you spawn a NNTP poco
 from within your own session. ARG0 is the poco's object.
 
-=item nntp_connected
+=item C<nntp_connected>
 
 Generated when the component successfully makes a connection to the NNTP server. Please note, that this is only the
 underlying network connection. Wait for either an 'nntp_200' or 'nntp_201' before sending any commands to the server.
 
-=item nntp_disconnected
+=item C<nntp_disconnected>
 
 Generated when the link to the NNTP server is dropped for whatever reason.
 
-=item nntp_socketerr
+=item C<nntp_socketerr>
 
 Generated when the component fails to establish a connection to the NNTP server.
 
-=item Numeric responses ( See RFC 977 )
+=item C<Numeric> responses ( See RFC 977 )
 
 Messages generated by NNTP servers consist of a numeric code and a text response. These will be sent to you as 
 events with the numeric code prefixed with 'nntp_'. ARG0 is the text response.
@@ -677,12 +677,12 @@ There are two types of handlers that can registered for by plugins, these are
 
 =over
 
-=item NNTPSERVER
+=item C<NNTPSERVER>
 
 These are the 'nntp_' prefixed events that are generated. In a handler arguments are
 passed as scalar refs so that you may mangle the values if required.
 
-=item NNTPCMD
+=item C<NNTPCMD>
 
 These are generated whenever an nntp command is sent to the component. Again, any 
 arguments passed are scalar refs for manglement.
@@ -701,23 +701,23 @@ The return values have the following significance:
 
 =over 
 
-=item NNTP_EAT_NONE
+=item C<NNTP_EAT_NONE>
 
 This means the event will continue to be processed by remaining plugins and
 finally, sent to interested sessions that registered for it.
 
-=item NNTP_EAT_CLIENT
+=item C<NNTP_EAT_CLIENT>
 
 This means the event will continue to be processed by remaining plugins but
 it will not be sent to any sessions that registered for it. This means nothing
 will be sent out on the wire if it was an NNTPCMD event, beware!
 
-=item NNTP_EAT_PLUGIN
+=item C<NNTP_EAT_PLUGIN>
 
 This means the event will not be processed by remaining plugins, it will go
 straight to interested sessions.
 
-=item NNTP_EAT_ALL
+=item C<NNTP_EAT_ALL>
 
 This means the event will be completely discarded, no plugin or session will see it. This
 means nothing will be sent out on the wire if it was an NNTPCMD event, beware!
@@ -730,11 +730,11 @@ The following methods are available:
 
 =over
 
-=item pipeline
+=item C<pipeline>
 
 Returns the L<POE::Component::Pluggable::Pipeline> object.
 
-=item plugin_add
+=item C<plugin_add>
 
 Accepts two arguments:
 
@@ -751,7 +751,7 @@ This method goes through the pipeline's push() method.
 Returns the number of plugins now in the pipeline if plugin was initialized, undef
 if not.
 
-=item plugin_del
+=item C<plugin_del>
 
 Accepts one argument:
 
@@ -763,7 +763,7 @@ This method will call $plugin->plugin_unregister( $irc )
 
 Returns the plugin object if the plugin was removed, undef if not.
 
-=item plugin_get
+=item C<plugin_get>
 
 Accepts one argument:
 
@@ -773,21 +773,21 @@ This method goes through the pipeline's get() method.
 
 Returns the plugin object if it was found, undef if not.
 
-=item plugin_list
+=item C<plugin_list>
 
 Has no arguments.
 
 Returns a hashref of plugin objects, keyed on alias, or an empty list if there are no
 plugins loaded.
 
-=item plugin_order
+=item C<plugin_order>
 
 Has no arguments.
 
 Returns an arrayref of plugin objects, in the order which they are encountered in the
 pipeline.
 
-=item plugin_register
+=item C<plugin_register>
 
 Accepts the following arguments:
 
@@ -804,7 +804,7 @@ It is possible to register for all events by specifying 'all' as an event.
 
 Returns 1 if everything checked out fine, undef if something's seriously wrong
 
-=item plugin_unregister
+=item C<plugin_unregister>
 
 Accepts the following arguments:
 
@@ -876,13 +876,13 @@ The group event sets the current working group on the server end. If you want to
 
 =head1 AUTHOR
 
-Chris Williams, E<lt>chris@bingosnet.co.uk<gt>
+Chris C<BinGOs> Williams, E<lt>chris@bingosnet.co.uk<gt>
 
 With code derived from L<POE::Component::IRC> by Dennis Taylor.
 
 =head1 LICENSE
 
-Copyright C<(c)> Chris Williams and Dennis Taylor.
+Copyright E<copy> Chris Williams and Dennis Taylor.
 
 This module may be used, modified, and distributed under the same terms as Perl itself. Please see the license that came with your Perl distribution for details.
 
